@@ -65,6 +65,9 @@
     <tags-item tags="num.*"/>
     <tags-item tags="num"/>
   </def-label>
+  <def-label name="WEB" closed="true">
+    <tags-item tags="web"/>
+  </def-label>
   <def-label name="PREDET" closed="true">
     <tags-item tags="predet.*"/>
   </def-label>
